@@ -9,18 +9,29 @@ use CGI::PSGI;
 
 use Class::Load ':all';
 
-use Hash::FieldHash ':all';
-
 use HTTP::Exception;
 
 use Log::Handler;
 
+use Moo;
+
 use Try::Tiny;
 
-fieldhash my %logger      => 'logger';
-fieldhash my %return_type => 'return_type';
+has logger =>
+(
+	is       => 'rw',
+	default  => sub{return ''},
+	required => 0,
+);
 
-our $VERSION = '1.04';
+has return_type =>
+(
+	is       => 'rw',
+	default  => sub{return 0},
+	required => 0,
+);
+
+our $VERSION = '2.00';
 
 # --------------------------------------------------
 
@@ -260,19 +271,6 @@ EOS
 
 # --------------------------------------------------
 
-sub _init
-{
-	my($self, $arg)    = @_;
-	$$arg{logger}      ||= ''; # Caller can set.
-	$$arg{return_type} ||= 0;  # Caller can set.
-	$self           = from_hash($self, $arg);
-
-	return $self;
-
-} # End of _init.
-
-# --------------------------------------------------
-
 sub log
 {
 	my($self, $level, $s) = @_;
@@ -382,18 +380,6 @@ sub _merge_args
 
 # --------------------------------------------------
 
-sub new
-{
-	my($class, %arg) = @_;
-	my($self)        = bless {}, $class;
-	$self            = $self -> _init(\%arg);
-
-	return $self;
-
-}	# End of new.
-
-# --------------------------------------------------
-
 sub _parse_error_document
 {
 	my($self, $error_document, $error_number) = @_;
@@ -1370,12 +1356,6 @@ Also, see t/logs.t, t/log.a.pl and t/log.b.pl.
 
 See also L<CGI::Snapp/What else do I need to know about logging?> for important info and sample code.
 
-=head2 This module uses Hash::FieldHash, which has an XS component!
-
-Yep.
-
-My policy is that stand-alone modules should use a light-weight object manager (my choice is L<Hash::FieldHash>), whereas apps can - and probably should - use L<Moose>.
-
 =head2 How do I sub-class CGI::Snapp::Dispatch?
 
 You do this the same way you sub-class L<CGI::Snapp>. See L<this FAQ entry in CGI::Snapp|CGI::Snapp#How-do-I-sub-class-CGI::Snapp->.
@@ -1510,7 +1490,7 @@ And see L<CGI::Snapp::Dispatch::Regexp> for another way of matching the path inf
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
@@ -1521,6 +1501,10 @@ Version numbers < 1.00 represent development versions. From 1.00 up, they are pr
 Please read L<CGI::Application::Dispatch/CONTRIBUTORS>, since this module is a fork of the non-Apache
 components of L<CGI::Application::Dispatch>.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/CGI-Snapp-Dispatch>
+
 =head1 Support
 
 Email the author, or log a bug on RT:
