@@ -6,9 +6,7 @@ use warnings;
 
 use Carp;
 
-use Hash::FieldHash ':all';
-
-our $VERSION = '1.04';
+our $VERSION = '2.00';
 
 # --------------------------------------------------
 
@@ -224,7 +222,7 @@ See L<CGI::Snapp::Dispatch/Troubleshooting>.
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
